@@ -173,7 +173,7 @@ class Model(object):
             for supercls in cls.__mro__:
                 if hasattr(supercls, '__visit_name__'):
                     cls = supercls
-                if supercls.__name__ != supercls.__name__.upper():
+                if supercls.__name__ != supercls.__name__.upper() and not supercls.__name__.startswith('_'):
                     break
 
             column.type = column.type.adapt(cls)
@@ -355,7 +355,10 @@ class ManyToOneRelationship(Relationship):
 
         colname = constraint.columns[0]
         tablename = constraint.elements[0].column.table.name
-        self.preferred_name = inflect_engine.singular_noun(tablename) if not colname.endswith('_id') else colname[:-3]
+        if not colname.endswith('_id'):
+            self.preferred_name = inflect_engine.singular_noun(tablename) or tablename
+        else:
+            self.preferred_name = colname[:-3]
 
         # Add uselist=False to One-to-One relationships
         if any(isinstance(c, (PrimaryKeyConstraint, UniqueConstraint)) and
