@@ -9,6 +9,7 @@ from sqlalchemy.schema import MetaData, Table, Column, CheckConstraint, UniqueCo
 from sqlalchemy.types import INTEGER, SMALLINT, VARCHAR, NUMERIC
 from sqlalchemy.dialects.postgresql.base import BIGINT, DOUBLE_PRECISION, BOOLEAN, ENUM
 from sqlalchemy.dialects.mysql.base import TINYINT
+from sqlalchemy.dialects.mysql import base as mysql
 
 from sqlacodegen.codegen import CodeGenerator
 
@@ -124,6 +125,28 @@ t_simple_items = Table(
     Column('id', BigInteger),
     Column('length', Float)
 )
+""")
+
+    def test_mysql_column_types(self):
+        Table(
+            'simple_items', self.metadata,
+            Column('id', mysql.INTEGER),
+            Column('name', mysql.VARCHAR(255))
+        )
+
+        eq_(self.generate_code(), """\
+# coding: utf-8
+from sqlalchemy import Column, Integer, MetaData, String, Table
+
+
+metadata = MetaData()
+
+
+t_simple_items = Table(
+    'simple_items', metadata,
+    Column('id', Integer),
+    Column('name', String(255))
+)
 """)
 
     def test_constraints_table(self):
@@ -509,6 +532,44 @@ class SimpleItem(Base):
     other_item = relationship('OtherItem', uselist=False)
 """)
 
+    def test_onetomany_noinflect(self):
+        Table(
+            'oglkrogk', self.metadata,
+            Column('id', INTEGER, primary_key=True),
+            Column('fehwiuhfiwID', INTEGER),
+            ForeignKeyConstraint(['fehwiuhfiwID'], ['fehwiuhfiw.id']),
+        )
+        Table(
+            'fehwiuhfiw', self.metadata,
+            Column('id', INTEGER, primary_key=True)
+        )
+
+        eq_(self.generate_code(), """\
+# coding: utf-8
+from sqlalchemy import Column, ForeignKey, Integer
+from sqlalchemy.orm import relationship
+from sqlalchemy.ext.declarative import declarative_base
+
+
+Base = declarative_base()
+metadata = Base.metadata
+
+
+class Fehwiuhfiw(Base):
+    __tablename__ = 'fehwiuhfiw'
+
+    id = Column(Integer, primary_key=True)
+
+
+class Oglkrogk(Base):
+    __tablename__ = 'oglkrogk'
+
+    id = Column(Integer, primary_key=True)
+    fehwiuhfiwID = Column(ForeignKey('fehwiuhfiw.id'))
+
+    fehwiuhfiw = relationship('Fehwiuhfiw')
+""")
+
     def test_manytomany(self):
         Table(
             'simple_items', self.metadata,
